==> mod_uploader-1.1.2.tgz: mod_uploader-1.1.2/include/PostReader.h <==
/******************************************************************************
 * mod_uploader / PostReader.cpp
 ******************************************************************************
 * Copyright (C) 2005 Tetsuya Kimata <kimata@acapulco.dyndns.org>
 *
 * All rights reserved.
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any
 * damages arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any
 * purpose, including commercial applications, and to alter it and
 * redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software. If you use this
 *    software in a product, an acknowledgment in the product
 *    documentation would be appreciated but is not required.
 *
 * 2. Altered source versions must be plainly marked as such, and must
 *    not be misrepresented as being the original software.
 *
 * 3. This notice may not be removed or altered from any source
 *    distribution.
 *
 * $Id: PostReader.h 569 2005-09-02 14:52:50Z svn $
 *****************************************************************************/

#ifndef POSTREADER_H
#define POSTREADER_H

#include "apr.h"

#include <cstdlib>

#ifdef HAVE_CONFIG_H
#include "mod_uploader_config.h"
#endif

using namespace std;

/**
 * @brief POST ꥯȤɤ߹९饹
 */
class PostReader
{
public:
    PostReader(apr_size_t block_size);
    virtual void read(char *buffer, apr_size_t size, apr_size_t *read_size) = 0;
    virtual ~PostReader();
protected:
    apr_size_t get_block_size();
private:
    apr_size_t block_size_;
};

#endif

// Local Variables:
// mode: c++
// buffer-file-coding-system: euc-japan-dos
// End:

==> mod_uploader-1.3.1.tgz: mod_uploader-1.3.1/include/PostReader.h <==
/******************************************************************************
 * mod_uploader / PostReader.cpp
 ******************************************************************************
 * Copyright (C) 2005 Tetsuya Kimata <kimata@acapulco.dyndns.org>
 *
 * All rights reserved.
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any
 * damages arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any
 * purpose, including commercial applications, and to alter it and
 * redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software. If you use this
 *    software in a product, an acknowledgment in the product
 *    documentation would be appreciated but is not required.
 *
 * 2. Altered source versions must be plainly marked as such, and must
 *    not be misrepresented as being the original software.
 *
 * 3. This notice may not be removed or altered from any source
 *    distribution.
 *
 * $Id: PostReader.h 638 2005-09-07 21:51:26Z svn $
 *****************************************************************************/

#ifndef POSTREADER_H
#define POSTREADER_H

#include "apr.h"
#include "apr_time.h"

#include <cstdlib>

#ifdef HAVE_CONFIG_H
#include "mod_uploader_config.h"
#endif

using namespace std;

/**
 * @brief POST ꥯȤɤ߹९饹
 */
class PostReader
{
public:
    typedef struct Progress {
        apr_size_t upload_id;
        apr_size_t total_size;
        apr_size_t read_size;
        apr_time_t end_time;
    } progress;

    PostReader(apr_size_t block_size, progress *progress);
    virtual void read(char *buffer, apr_size_t size, apr_size_t *read_size) = 0;
    virtual ~PostReader();

protected:
    void update(apr_size_t read_size);
    apr_size_t get_block_size();

private:
    apr_size_t block_size_;
    progress *progress_;
};

#endif

// Local Variables:
// mode: c++
// buffer-file-coding-system: euc-japan-dos
// End:
